# Gallery of Examples

This page consists of the 'General example' gallery and a sub-gallery,
'No image output examples'. This sub-gallery is generated from a
sub-directory within the general examples directory. The file structure of
this gallery looks like this:

```
examples/           # base 'Gallery of Examples' directory
├── README.txt
├── <.py files>
└── no_output/      # generates the 'No image output examples' sub-gallery
    ├── README.txt
    └── <.py files>
```

## General examples

This gallery consists of introductory examples and examples demonstrating
specific features of Mkdocs-Gallery.
